"""Definition of chips."""
AM33XX = "AM33XX"
DRA74X = "DRA74X"
IMX6ULL = "IMX6ULL"
IMX8MX = "IMX8MX"
BCM2XXX = "BCM2XXX"
ESP8266 = "ESP8266"
EXYNOS5422 = "EXYNOS5422"
RYZEN_V1202B = "RYZEN_V1202B"
RYZEN_V1605B = "RYZEN_V1605B"
SAMD21 = "SAMD21"
SUN8I = "SUN8I"
S805 = "S805"
S905 = "S905"
S905X3 = "S905X3"
S922X = "S922X"
SAMA5 = "SAMA5"
T210 = "T210"
T186 = "T186"
T194 = "T194"
APQ8016 = "APQ8016"
GENERIC_X86 = "GENERIC_X86"
FT232H = "FT232H"
FT2232H = "FT2232H"
HFU540 = "HFU540"
C906 = "C906"
VICU7 = "VICU7"
MCP2221 = "MCP2221"
BINHO = "BINHO"
MIPS24KC = "MIPS24KC"
MIPS24KEC = "MIPS24KEC"
ZYNQ7000 = "ZYNQ7000"
A64 = "A64"
H6 = "H6"
A33 = "A33"
H5 = "H5"
H616 = "H616"
RK3308 = "RK3308"
RK3399 = "RK3399"
RK3328 = "RK3328"
LPC4330 = "LPC4330"
RK3288 = "RK3288"
PENTIUM_N3710 = "PENTIUM_N3710"  # SOC Braswell core
STM32F405 = "STM32F405"
RP2040 = "RP2040"
STM32MP157 = "STM32MP157"
MT8167 = "MT8167"
ATOM_X5_Z8350 = "X5-Z8350"
PICO_U2IF = "PICO_U2IF"
FEATHER_U2IF = "FEATHER_U2IF"
ITSYBITSY_U2IF = "ITSYBITSY_U2IF"
QTPY_U2IF = "QTPY_U2IF"
QT2040_TRINKEY_U2IF = "QT2040_TRINKEY_U2IF"


BCM_RANGE = {"BCM2708", "BCM2709", "BCM2711", "BCM2835", "BCM2837"}
